"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const documents_1 = require("../../documents");
const HoverProvider_1 = require("../HoverProvider");
(0, vitest_1.describe)('Module: LiquidObjectAttributeHoverProvider', async () => {
    let provider;
    (0, vitest_1.beforeEach)(async () => {
        provider = new HoverProvider_1.HoverProvider(new documents_1.DocumentManager(), {
            filters: async () => [],
            objects: async () => [
                {
                    name: 'product',
                    description: 'product description',
                    return_type: [],
                    properties: [
                        {
                            name: 'featured_image',
                            description: 'featured_image description',
                            return_type: [{ type: 'image', name: '' }],
                        },
                        {
                            name: 'title',
                            return_type: [{ type: 'string', name: '' }],
                        },
                    ],
                },
                {
                    name: 'image',
                    description: 'image description',
                    access: {
                        global: false,
                        parents: [],
                        template: [],
                    },
                },
            ],
            tags: async () => [],
        });
    });
    (0, vitest_1.it)('should return the hover description of the object property', async () => {
        const contexts = [
            '{{ product.feat█ured_image }}',
            '{{ product.featured_image█ }}',
            '{% echo product.featured_image█ %}',
            '{% liquid\n echo product.featured_image█ %}',
        ];
        for (const context of contexts) {
            await (0, vitest_1.expect)(provider).to.hover(context, vitest_1.expect.stringContaining('featured_image description'));
            await (0, vitest_1.expect)(provider).to.hover(context, vitest_1.expect.stringMatching(/##* featured_image: `image`/));
        }
    });
    (0, vitest_1.it)('should return nothing if there are no docs for that attribute', async () => {
        await (0, vitest_1.expect)(provider).to.hover(`{{ product.featured_foo█ }}`, null);
    });
});
//# sourceMappingURL=LiquidObjectAttributeHoverProvider.spec.js.map